==> globaltest_5.6.1.zip: globaltest/doc/GlobalTest_deprecated.R <==
###################################################
### chunk number 1: library
###################################################
#line 32 "GlobalTest_deprecated.Rnw"
library(globaltest)


###################################################
### chunk number 2: deprecated
###################################################
#line 35 "GlobalTest_deprecated.Rnw"
gt.options(warn.deprecated=FALSE)


###################################################
### chunk number 3: options
###################################################
#line 118 "GlobalTest_deprecated.Rnw"
options(continue = "  ")


###################################################
### chunk number 4: getGolubData
###################################################
#line 130 "GlobalTest_deprecated.Rnw"
library(golubEsets)
library(vsn)
data(Golub_Merge)
Golub<-Golub_Merge[,1:34]
exprs(Golub)<-exprs(vsn2(Golub_Merge[,1:34]))


###################################################
### chunk number 5: getNKIData
###################################################
#line 158 "GlobalTest_deprecated.Rnw"
library(globaltest)
data(vandeVijver)


###################################################
### chunk number 6: loadKEGGandGO
###################################################
#line 182 "GlobalTest_deprecated.Rnw"
library(hu6800.db)
kegg <- as.list(hu6800PATH2PROBE)
go <- as.list(hu6800GO2ALLPROBES)


###################################################
### chunk number 7: cleanGO
###################################################
#line 197 "GlobalTest_deprecated.Rnw"
go <- lapply(go, function(x) x[!is.na(names(x)) & (names(x) != "IEA")])


###################################################
### chunk number 8: makeCellcycle
###################################################
#line 203 "GlobalTest_deprecated.Rnw"
GO.cellcycle <- go[["GO:0007049"]]
KEGG.cellcycle <- kegg[["04110"]]


###################################################
### chunk number 9: all
###################################################
#line 230 "GlobalTest_deprecated.Rnw"
gt.all <- globaltest(Golub, "ALL.AML")


###################################################
### chunk number 10: all.display
###################################################
#line 251 "GlobalTest_deprecated.Rnw"
gt.all


###################################################
### chunk number 11: cellcycle
###################################################
#line 282 "GlobalTest_deprecated.Rnw"
globaltest(Golub, "ALL.AML", GO.cellcycle)


###################################################
### chunk number 12: twocellcycle
###################################################
#line 309 "GlobalTest_deprecated.Rnw"
cellcycle <- list(go = GO.cellcycle, kegg = KEGG.cellcycle)
globaltest(Golub, "ALL.AML", cellcycle)


###################################################
### chunk number 13: kegg
###################################################
#line 318 "GlobalTest_deprecated.Rnw"
gt.kegg <- globaltest(Golub, "ALL.AML", kegg)


###################################################
### chunk number 14: kegg.display eval=FALSE
###################################################
## #line 326 "GlobalTest_deprecated.Rnw"
## gt.kegg["04110"]
## gt.kegg[1:10]


###################################################
### chunk number 15: sort.by.p
###################################################
#line 334 "GlobalTest_deprecated.Rnw"
sorted <- sort(gt.kegg)
top5 <- sorted[1:5]
top5


###################################################
### chunk number 16: kegg.numbers.to.names
###################################################
#line 344 "GlobalTest_deprecated.Rnw"
library(KEGG.db)
names(top5) <- as.list(KEGGPATHID2NAME)[names(top5)]
top5


###################################################
### chunk number 17: useful
###################################################
#line 354 "GlobalTest_deprecated.Rnw"
p.value(top5)
names(top5)
result(top5)
length(top5)


###################################################
### chunk number 18: multtest
###################################################
#line 365 "GlobalTest_deprecated.Rnw"
sorted <- gt.multtest(sorted, "FWER")
sorted[1:5]


###################################################
### chunk number 19: golub_Source
###################################################
#line 405 "GlobalTest_deprecated.Rnw"
globaltest(Golub, "Source")


###################################################
### chunk number 20: golub_Source_2levels
###################################################
#line 415 "GlobalTest_deprecated.Rnw"
globaltest(Golub, "Source", levels = c("CALGB", "CCG"))


###################################################
### chunk number 21: golub_Source_1level
###################################################
#line 425 "GlobalTest_deprecated.Rnw"
globaltest(Golub, "Source", levels = "St-Jude")


###################################################
### chunk number 22: golub_Source_factor eval=FALSE
###################################################
## #line 434 "GlobalTest_deprecated.Rnw"
## globaltest(Golub, "factor(Source)")


###################################################
### chunk number 23: golub_pctBlasts
###################################################
#line 448 "GlobalTest_deprecated.Rnw"
calgb <- pData(Golub)["Source"] == "CALGB"
globaltest(Golub[,calgb], "pctBlasts")


###################################################
### chunk number 24: vandeVijver_survival
###################################################
#line 460 "GlobalTest_deprecated.Rnw"
library(survival)
globaltest(vandeVijver, "Surv(TIMEsurvival, EVENTdeath)")


###################################################
### chunk number 25: vandeVijver_survival_alternatives eval=FALSE
###################################################
## #line 470 "GlobalTest_deprecated.Rnw"
## globaltest(vandeVijver, "Surv(TIMEsurvival, EVENTdeath == 1)")
## globaltest(vandeVijver, "TIMEsurvival", d = "EVENTdeath")
## globaltest(vandeVijver, "TIMEsurvival", d = "EVENTdeath", event = 1)


###################################################
### chunk number 26: method
###################################################
#line 551 "GlobalTest_deprecated.Rnw"
globaltest(Golub, "ALL.AML", GO.cellcycle, method = "p", nperm = 1000)


###################################################
### chunk number 27: permutations
###################################################
#line 563 "GlobalTest_deprecated.Rnw"
gt <- globaltest(Golub, "ALL.AML", GO.cellcycle)
permutations(gt, nperm = 2000)


###################################################
### chunk number 28: golub_adjust_BM.PB
###################################################
#line 620 "GlobalTest_deprecated.Rnw"
globaltest(Golub, ALL.AML ~ BM.PB, GO.cellcycle)


###################################################
### chunk number 29: vijver_adjust_all
###################################################
#line 644 "GlobalTest_deprecated.Rnw"
globaltest(vandeVijver, Surv(TIMEsurvival, EVENTdeath) ~ NIH + ESR1 + Posnodes)


###################################################
### chunk number 30: vijver_esr1
###################################################
#line 655 "GlobalTest_deprecated.Rnw"
globaltest(vandeVijver, "ESR1")


###################################################
### chunk number 31: golub_adjust_AML.ALL
###################################################
#line 665 "GlobalTest_deprecated.Rnw"
gt <- globaltest(vandeVijver, Surv(TIMEsurvival, EVENTdeath) ~ ESR1)
fit(gt)


###################################################
### chunk number 32: sampling
###################################################
#line 688 "GlobalTest_deprecated.Rnw"
gt <- globaltest(Golub, "ALL.AML", KEGG.cellcycle)
sampled.gt <- sampling(gt)
sampled.gt


###################################################
### chunk number 33: hist eval=FALSE
###################################################
## #line 741 "GlobalTest_deprecated.Rnw"
## gt <- globaltest(Golub, "ALL.AML", KEGG.cellcycle, method = "p")
## hist(gt)


###################################################
### chunk number 34: hist-plot
###################################################
#line 747 "GlobalTest_deprecated.Rnw"
gt <- globaltest(Golub, "ALL.AML", KEGG.cellcycle, method = "p")
hist(gt)


###################################################
### chunk number 35: geneplot
###################################################
#line 787 "GlobalTest_deprecated.Rnw"
gt <- globaltest(Golub, "ALL.AML", kegg)
geneplot(gt, "00561")


###################################################
### chunk number 36: geneplot_store
###################################################
#line 804 "GlobalTest_deprecated.Rnw"
myplot <- geneplot(gt, "00561", plot = FALSE)


###################################################
### chunk number 37: geneplot_changenames
###################################################
#line 815 "GlobalTest_deprecated.Rnw"
names(myplot) <- as.list(hu6800SYMBOL)[names(myplot)]
plot(myplot)


###################################################
### chunk number 38: geneplot_changenames2
###################################################
#line 827 "GlobalTest_deprecated.Rnw"
plot(myplot)


###################################################
### chunk number 39: geneplot_sort
###################################################
#line 836 "GlobalTest_deprecated.Rnw"
mysorted <- sort(myplot)
top5 <- mysorted[1:5]


###################################################
### chunk number 40: geneplot_utilities
###################################################
#line 846 "GlobalTest_deprecated.Rnw"
z.score(top5)
names(top5)
result(top5)
length(top5)


###################################################
### chunk number 41: sampleplot
###################################################
#line 889 "GlobalTest_deprecated.Rnw"
gt <- globaltest(Golub, "ALL.AML", KEGG.cellcycle)
sampleplot(gt)


###################################################
### chunk number 42: sampleplot-plot
###################################################
#line 904 "GlobalTest_deprecated.Rnw"
sampleplot(gt)


###################################################
### chunk number 43: checkerboard
###################################################
#line 930 "GlobalTest_deprecated.Rnw"
gt <- globaltest(Golub, "ALL.AML", kegg)
checkerboard(gt.kegg, "04110")


###################################################
### chunk number 44: checkerboard-plot
###################################################
#line 943 "GlobalTest_deprecated.Rnw"
checkerboard(gt, "04110")


###################################################
### chunk number 45: regressionplot
###################################################
#line 976 "GlobalTest_deprecated.Rnw"
gt <- globaltest(Golub, "ALL.AML", kegg)
regressionplot(gt, "04110", sampleid = "39")


###################################################
### chunk number 46: regressionplot2
###################################################
#line 984 "GlobalTest_deprecated.Rnw"
regressionplot(gt, "04110", sampleid = c("39","40"))


###################################################
### chunk number 47: regressionplot-plot
###################################################
#line 991 "GlobalTest_deprecated.Rnw"
regressionplot(gt, "04110", "39")


###################################################
### chunk number 48: 
###################################################
#line 1000 "GlobalTest_deprecated.Rnw"
toLatex(sessionInfo())

==> globaltest_5.8.1.zip: globaltest/doc/GlobalTest_deprecated.R <==
### R code from vignette source 'GlobalTest_deprecated.Rnw'

###################################################
### code chunk number 1: library
###################################################
library(globaltest)


###################################################
### code chunk number 2: deprecated
###################################################
gt.options(warn.deprecated=FALSE)


###################################################
### code chunk number 3: options
###################################################
options(continue = "  ")


###################################################
### code chunk number 4: getGolubData
###################################################
library(golubEsets)
library(vsn)
data(Golub_Merge)
Golub<-Golub_Merge[,1:34]
exprs(Golub)<-exprs(vsn2(Golub_Merge[,1:34]))


###################################################
### code chunk number 5: getNKIData
###################################################
library(globaltest)
data(vandeVijver)


###################################################
### code chunk number 6: loadKEGGandGO
###################################################
library(hu6800.db)
kegg <- as.list(hu6800PATH2PROBE)
go <- as.list(hu6800GO2ALLPROBES)


###################################################
### code chunk number 7: cleanGO
###################################################
go <- lapply(go, function(x) x[!is.na(names(x)) & (names(x) != "IEA")])


###################################################
### code chunk number 8: makeCellcycle
###################################################
GO.cellcycle <- go[["GO:0007049"]]
KEGG.cellcycle <- kegg[["04110"]]


###################################################
### code chunk number 9: all
###################################################
gt.all <- globaltest(Golub, "ALL.AML")


###################################################
### code chunk number 10: all.display
###################################################
gt.all


###################################################
### code chunk number 11: cellcycle
###################################################
globaltest(Golub, "ALL.AML", GO.cellcycle)


###################################################
### code chunk number 12: twocellcycle
###################################################
cellcycle <- list(go = GO.cellcycle, kegg = KEGG.cellcycle)
globaltest(Golub, "ALL.AML", cellcycle)


###################################################
### code chunk number 13: kegg
###################################################
gt.kegg <- globaltest(Golub, "ALL.AML", kegg)


###################################################
### code chunk number 14: kegg.display (eval = FALSE)
###################################################
## gt.kegg["04110"]
## gt.kegg[1:10]


###################################################
### code chunk number 15: sort.by.p
###################################################
sorted <- sort(gt.kegg)
top5 <- sorted[1:5]
top5


###################################################
### code chunk number 16: kegg.numbers.to.names
###################################################
library(KEGG.db)
names(top5) <- as.list(KEGGPATHID2NAME)[names(top5)]
top5


###################################################
### code chunk number 17: useful
###################################################
p.value(top5)
names(top5)
result(top5)
length(top5)


###################################################
### code chunk number 18: multtest
###################################################
sorted <- gt.multtest(sorted, "FWER")
sorted[1:5]


###################################################
### code chunk number 19: golub_Source
###################################################
globaltest(Golub, "Source")


###################################################
### code chunk number 20: golub_Source_2levels
###################################################
globaltest(Golub, "Source", levels = c("CALGB", "CCG"))


###################################################
### code chunk number 21: golub_Source_1level
###################################################
globaltest(Golub, "Source", levels = "St-Jude")


###################################################
### code chunk number 22: golub_Source_factor (eval = FALSE)
###################################################
## globaltest(Golub, "factor(Source)")


###################################################
### code chunk number 23: golub_pctBlasts
###################################################
calgb <- pData(Golub)["Source"] == "CALGB"
globaltest(Golub[,calgb], "pctBlasts")


###################################################
### code chunk number 24: vandeVijver_survival
###################################################
library(survival)
globaltest(vandeVijver, "Surv(TIMEsurvival, EVENTdeath)")


###################################################
### code chunk number 25: vandeVijver_survival_alternatives (eval = FALSE)
###################################################
## globaltest(vandeVijver, "Surv(TIMEsurvival, EVENTdeath == 1)")
## globaltest(vandeVijver, "TIMEsurvival", d = "EVENTdeath")
## globaltest(vandeVijver, "TIMEsurvival", d = "EVENTdeath", event = 1)


###################################################
### code chunk number 26: method
###################################################
globaltest(Golub, "ALL.AML", GO.cellcycle, method = "p", nperm = 1000)


###################################################
### code chunk number 27: permutations
###################################################
gt <- globaltest(Golub, "ALL.AML", GO.cellcycle)
permutations(gt, nperm = 2000)


###################################################
### code chunk number 28: golub_adjust_BM.PB
###################################################
globaltest(Golub, ALL.AML ~ BM.PB, GO.cellcycle)


###################################################
### code chunk number 29: vijver_adjust_all
###################################################
globaltest(vandeVijver, Surv(TIMEsurvival, EVENTdeath) ~ NIH + ESR1 + Posnodes)


###################################################
### code chunk number 30: vijver_esr1
###################################################
globaltest(vandeVijver, "ESR1")


###################################################
### code chunk number 31: golub_adjust_AML.ALL
###################################################
gt <- globaltest(vandeVijver, Surv(TIMEsurvival, EVENTdeath) ~ ESR1)
fit(gt)


###################################################
### code chunk number 32: sampling
###################################################
gt <- globaltest(Golub, "ALL.AML", KEGG.cellcycle)
sampled.gt <- sampling(gt)
sampled.gt


###################################################
### code chunk number 33: hist (eval = FALSE)
###################################################
## gt <- globaltest(Golub, "ALL.AML", KEGG.cellcycle, method = "p")
## hist(gt)


###################################################
### code chunk number 34: hist-plot
###################################################
gt <- globaltest(Golub, "ALL.AML", KEGG.cellcycle, method = "p")
hist(gt)


###################################################
### code chunk number 35: geneplot
###################################################
gt <- globaltest(Golub, "ALL.AML", kegg)
geneplot(gt, "00561")


###################################################
### code chunk number 36: geneplot_store
###################################################
myplot <- geneplot(gt, "00561", plot = FALSE)


###################################################
### code chunk number 37: geneplot_changenames
###################################################
names(myplot) <- as.list(hu6800SYMBOL)[names(myplot)]
plot(myplot)


###################################################
### code chunk number 38: geneplot_changenames2
###################################################
plot(myplot)


###################################################
### code chunk number 39: geneplot_sort
###################################################
mysorted <- sort(myplot)
top5 <- mysorted[1:5]


###################################################
### code chunk number 40: geneplot_utilities
###################################################
z.score(top5)
names(top5)
result(top5)
length(top5)


###################################################
### code chunk number 41: sampleplot
###################################################
gt <- globaltest(Golub, "ALL.AML", KEGG.cellcycle)
sampleplot(gt)


###################################################
### code chunk number 42: sampleplot-plot
###################################################
sampleplot(gt)


###################################################
### code chunk number 43: checkerboard
###################################################
gt <- globaltest(Golub, "ALL.AML", kegg)
checkerboard(gt.kegg, "04110")


###################################################
### code chunk number 44: checkerboard-plot
###################################################
checkerboard(gt, "04110")


###################################################
### code chunk number 45: regressionplot
###################################################
gt <- globaltest(Golub, "ALL.AML", kegg)
regressionplot(gt, "04110", sampleid = "39")


###################################################
### code chunk number 46: regressionplot2
###################################################
regressionplot(gt, "04110", sampleid = c("39","40"))


###################################################
### code chunk number 47: regressionplot-plot
###################################################
regressionplot(gt, "04110", "39")


###################################################
### code chunk number 48: GlobalTest_deprecated.Rnw:999-1000
###################################################
toLatex(sessionInfo())
